summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/model_utils.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/model_utils.h')
-rw-r--r--umbrello/umbrello/model_utils.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/umbrello/umbrello/model_utils.h b/umbrello/umbrello/model_utils.h
index 6660ff64..1e8bd83b 100644
--- a/umbrello/umbrello/model_utils.h
+++ b/umbrello/umbrello/model_utils.h
@@ -236,7 +236,7 @@ Uml::Programming_Language stringToProgLang(TQString str);
/**
* Return type of parseOperation()
*/
-enum Parse_tqStatus {
+enum Parse_Status {
PS_OK, PS_Empty, PS_Malformed_Arg, PS_Unknown_ArgType,
PS_Illegal_MethodName, PS_Unknown_ReturnType, PS_Unspecified_Error
};
@@ -284,7 +284,7 @@ struct OpDescriptor {
* @param owningScope Pointer to the owning scope of the template param.
* @return Error status of the parse, PS_OK for success.
*/
-Parse_tqStatus parseTemplate(TQString t, NameAndType& nmTp, UMLClassifier *owningScope);
+Parse_Status parseTemplate(TQString t, NameAndType& nmTp, UMLClassifier *owningScope);
/**
* Parses an attribute given in UML syntax.
@@ -303,7 +303,7 @@ Parse_tqStatus parseTemplate(TQString t, NameAndType& nmTp, UMLClassifier *ownin
*
* @return Error status of the parse, PS_OK for success.
*/
-Parse_tqStatus parseAttribute(TQString a, NameAndType& nmTp, UMLClassifier *owningScope,
+Parse_Status parseAttribute(TQString a, NameAndType& nmTp, UMLClassifier *owningScope,
Uml::Visibility *vis = 0);
/**
@@ -316,12 +316,12 @@ Parse_tqStatus parseAttribute(TQString a, NameAndType& nmTp, UMLClassifier *owni
* @param owningScope Pointer to the owning scope of the operation.
* @return Error status of the parse, PS_OK for success.
*/
-Parse_tqStatus parseOperation(TQString m, OpDescriptor& desc, UMLClassifier *owningScope);
+Parse_Status parseOperation(TQString m, OpDescriptor& desc, UMLClassifier *owningScope);
/**
* Returns the Parse_tqStatus as a text.
*/
-TQString psText(Parse_tqStatus value);
+TQString psText(Parse_Status value);
}
@@ -316,12 +316,12 @@ Parse_tqStatus parseAttribute(TQString a, NameAndType& nmTp, UMLClassifier *owni
/**
- * Returns the Parse_tqStatus as a text.
+ * Returns the Parse_Status as a text.
*/